/*
 *  Copyright 2001-2009 Internet2
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file xmltooling/security/CredentialContext.h
 * 
 * Marker interface for implementations which hold information specific to a
 * particular context within which a CredentialResolver resolves a Credential.
 */

#if !defined(__xmltooling_credctx_h__) && !defined(XMLTOOLING_NO_XMLSEC)
#define __xmltooling_credctx_h__

#include <xmltooling/base.h>

namespace xmltooling {

    /**
     * Marker interface for implementations which hold information specific to a
     * particular context within which a CredentialResolver resolves a Credential.
     */
    class XMLTOOL_API CredentialContext
    {
        MAKE_NONCOPYABLE(CredentialContext);
    protected:
        CredentialContext();
        
    public:
        virtual ~CredentialContext();
        
    };
};

#endif /* __xmltooling_credctx_h__ */
